Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "JmolInChI");
;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
